Release Notes — Translate Toolkit 3.3.4 documentation

# Release Notes

The following are release notes for the Translate Toolkit releases.

These are the changes that have happened in the Translate Toolkit and which may impact you. If you use Pootle, Virtaal or any other application that makes use of the Translate Toolkit you may want to familiarize yourself with these changes.

## Final releases

- 3.3.4
- 3.3.3
- 3.3.2
- 3.3.1
- 3.3.0
- 3.2.0
- 3.1.1
- 3.1.0
- 3.0.0
- 2.5.1
- 2.5.0
- 2.4.0
- 2.3.1
- 2.3.0
- 2.2.5
- 2.2.4
- 2.2.3
- 2.2.2
- 2.2.1
- 2.2.0
- 2.1.0
- 2.0.0
- 1.13.0
- 1.12.0
- 1.11.0
- 1.10.0
- 1.9.0
- 1.8.1

## Historic releases

- Translate Toolkit 1.8.0
- Translate Toolkit 1.7.0
- 1.6.0
- Translate Toolkit 1.5.3
- Translate Toolkit 1.5.2
- Translate Toolkit 1.5.1
- Translate Toolkit 1.5.0
- 1.4.1
- 1.4.0
- 1.3.0
- Translate Toolkit 1.2.1
- Translate Toolkit 1.2.0
- branches
- 1.1.1
- 1.1.0
- 1.0.1
- 1.0
- 0.11
- Translate Toolkit 0.10.1
- 0.10
- Translate Toolkit 0.9.2
- Translate Toolkit 0.9.1
- 0.9
- Translate Toolkit 0.8
- Translate Toolkit 0.7.1